@@ -13,9 +13,9 @@ from streamlink.stream.hls import HLSStream
 from streamlink.utils.url import update_scheme
 
 
-@pluginmatcher(re.compile(
-    r"https?://player\.invintus\.com/\?clientID=(\d+)&eventID=(\d+)"
-))
+@pluginmatcher(
+    re.compile(r"https?://player\.invintus\.com/\?clientID=(\d+)&eventID=(\d+)"),
+)
 class InvintusMedia(Plugin):
     WSC_API_KEY = "7WhiEBzijpritypp8bqcU7pfU9uicDR"  # hard coded in the middle of https://player.invintus.com/app.js
     API_URL = "https://api.v3.invintusmedia.com/v2/Event/getDetailed"
@@ -31,12 +31,12 @@ class InvintusMedia(Plugin):
             "includePrivate": False,
             "advancedDetails": True,
             "VAST": True,
-            "eventID": self.match.group(2)
+            "eventID": self.match.group(2),
         }
         headers = {
             "Content-Type": "application/json",
             "wsc-api-key": self.WSC_API_KEY,
-            "Authorization": "embedder"
+            "Authorization": "embedder",
         }
         res = self.session.http.post(self.API_URL, data=json.dumps(postdata), headers=headers)
         api_response = self.session.http.json(res, schema=self.api_response_schema)
