@@ -1,15 +1,17 @@
+# ruff: noqa: RUF067
+
 import json
-from contextlib import contextmanager
 from datetime import datetime as _datetime
 
 from streamlink_cli.utils.formatter import Formatter
-from streamlink_cli.utils.http_server import HTTPServer
 from streamlink_cli.utils.player import find_default_player
 
+
 __all__ = [
-    "Formatter", "HTTPServer", "JSONEncoder",
+    "Formatter",
+    "JSONEncoder",
     "datetime",
-    "find_default_player", "ignored",
+    "find_default_player",
 ]
 
 
@@ -23,14 +25,6 @@ class JSONEncoder(json.JSONEncoder):
             return json.JSONEncoder.default(self, obj)
 
 
-@contextmanager
-def ignored(*exceptions):
-    try:
-        yield
-    except exceptions:
-        pass
-
-
 # noinspection PyPep8Naming
 class datetime(_datetime):
     def __str__(self):
