@@ -1,25 +1,33 @@
 from __future__ import annotations
 
 import contextlib
-from collections.abc import Generator
 from contextlib import nullcontext
 from dataclasses import dataclass
 from functools import partial
+from typing import TYPE_CHECKING
 from unittest.mock import AsyncMock
 
 import pytest
 import trio
-from trio.testing import MockClock, wait_all_tasks_blocked
+from trio.testing import wait_all_tasks_blocked
 from trio_websocket import CloseReason, ConnectionClosed, ConnectionTimeout  # type: ignore[import]
 
 from streamlink.compat import ExceptionGroup
-from streamlink.webbrowser.cdp.connection import MAX_BUFFER_SIZE, CDPConnection, CDPEventListener, CDPSession
+from streamlink.webbrowser.cdp.connection import MAX_BUFFER_SIZE, CDPConnection, CDPSession
 from streamlink.webbrowser.cdp.devtools.target import SessionID, TargetID
-from streamlink.webbrowser.cdp.devtools.util import T_JSON_DICT
 from streamlink.webbrowser.cdp.exceptions import CDPError
 from tests.webbrowser.cdp import FakeWebsocketConnection
 
 
+if TYPE_CHECKING:
+    from collections.abc import Generator
+
+    from trio.testing import MockClock
+
+    from streamlink.webbrowser.cdp.connection import CDPEventListener
+    from streamlink.webbrowser.cdp.devtools.util import T_JSON_DICT
+
+
 EPSILON = 0.1
 
 
